@@ -101,20 +101,21 @@ class DiffusionAPI(APIMixin):
         *,
         use_amp: bool = False,
         use_half: bool = False,
+        clip_skip: int = 0,
     ):
         super().__init__(m, device, use_amp=use_amp, use_half=use_half)
         self.sampler = m.sampler
         self.cond_type = m.condition_type
+        self.clip_skip = clip_skip
         # extracted the condition model so we can pre-calculate the conditions
         self.cond_model = m.condition_model
         if self.cond_model is not None:
             self.cond_model.eval()
         m.condition_model = nn.Identity()
         # pre-calculate unconditional_cond if needed
-        unconditional_cond = getattr(m.sampler, "unconditional_cond", None)
-        if self.cond_model is not None and unconditional_cond is not None:
-            uncond = self.get_cond(unconditional_cond)
-            m.sampler.unconditional_cond = uncond.to(self.device)
+        self._original_raw_uncond = getattr(m.sampler, "unconditional_cond", None)
+        self._uncond_cache: tensor_dict_type = {}
+        self._update_sampler_uncond(clip_skip)
         # extract first stage
         if not isinstance(m, LDM):
             self.first_stage = None
@@ -229,8 +230,12 @@ class DiffusionAPI(APIMixin):
     ) -> Tensor:
         registered_custom = False
         if self.cond_model is not None:
+            clip_skip = kwargs.get(
+                "clip_skip",
+                0 if self.clip_skip is None else self.clip_skip,
+            )
+            self._update_sampler_uncond(clip_skip)
             if isinstance(self.cond_model, CLIPTextConditionModel):
-                self.cond_model.clip_skip = kwargs.get("clip_skip", 0)
                 custom_embeddings = kwargs.get("custom_embeddings")
                 if custom_embeddings is not None:
                     registered_custom = True
@@ -388,6 +393,21 @@ class DiffusionAPI(APIMixin):
             self.cond_model.clear_custom()
         return concat
 
+    def _update_clip_skip(self, clip_skip: int) -> None:
+        if isinstance(self.cond_model, CLIPTextConditionModel):
+            self.cond_model.clip_skip = clip_skip
+
+    def _update_sampler_uncond(self, clip_skip: int) -> None:
+        self._update_clip_skip(clip_skip)
+        if self.cond_model is not None and self._original_raw_uncond is not None:
+            cache = self._uncond_cache.get(clip_skip)
+            if cache is not None:
+                uncond = cache
+            else:
+                uncond = self.get_cond(self._original_raw_uncond)
+                self._uncond_cache[clip_skip] = uncond
+            self.m.sampler.unconditional_cond = uncond.to(self.device)
+
     @staticmethod
     def _txt_cond(t: Union[str, List[str]], n: Optional[int]) -> Tuple[List[str], int]:
         if n is None:
@@ -826,6 +846,38 @@ class DiffusionAPI(APIMixin):
         m = ldm_sd_inpainting()
         return cls.from_pipeline(m, device, use_amp=use_amp, use_half=use_half)
 
+    @classmethod
+    def from_sd_v2(
+        cls,
+        device: Optional[str] = None,
+        *,
+        use_amp: bool = False,
+        use_half: bool = False,
+    ) -> "DiffusionAPI":
+        return cls.from_pipeline(
+            ldm_sd_v2(),
+            device,
+            use_amp=use_amp,
+            use_half=use_half,
+            clip_skip=1,
+        )
+
+    @classmethod
+    def from_sd_v2_base(
+        cls,
+        device: Optional[str] = None,
+        *,
+        use_amp: bool = False,
+        use_half: bool = False,
+    ) -> "DiffusionAPI":
+        return cls.from_pipeline(
+            ldm_sd_v2_base(),
+            device,
+            use_amp=use_amp,
+            use_half=use_half,
+            clip_skip=1,
+        )
+
     @classmethod
     def from_celeba_hq(
         cls,
@@ -933,8 +985,8 @@ class DiffusionAPI(APIMixin):
         with switch_sampler_context(self, kwargs.get("sampler")):
             if num_steps is None:
                 num_steps = self.sampler.default_steps
-            t = round((1.0 - fidelity) * num_steps)
-            ts = get_timesteps(min(t, num_steps - 1), 1, z.device)
+            t = min(num_steps, round((1.0 - fidelity) * (num_steps + 1)))
+            ts = get_timesteps(t, 1, z.device)
             if isinstance(self.sampler, (DDIMMixin, KSamplerMixin, DPMSolver)):
                 kw = shallow_copy_dict(self.sampler.sample_kwargs)
                 kw["total_step"] = num_steps
@@ -1043,6 +1095,10 @@ def ldm_sd_v2(pretrained: bool = True, **kwargs: Any) -> DLPipeline:
     return _ldm("diffusion/ldm.sd_v2", 64, 4, 4, pretrained=pretrained, **kwargs)
 
 
+def ldm_sd_v2_base(pretrained: bool = True, **kwargs: Any) -> DLPipeline:
+    return _ldm("diffusion/ldm.sd_v2_base", 64, 4, 4, pretrained=pretrained, **kwargs)
+
+
 def ldm_celeba_hq(pretrained: bool = True) -> DLPipeline:
     return ldm_vq(
         pretrained=pretrained,
